s = "aeiou"
k = 2
class lee:
    if __name__ == '__main__':
        left = 0
        right = 0
        maxnum = 0
        amax = 0
        st = ['a','e','i','o','u']
        while right < len(s):
            if s[right] in st:
                maxnum += 1
            right += 1
            if right >= k:
                amax = max(maxnum,amax)
                if s[left] in st:
                    maxnum -= 1
                left += 1

        print(amax)



from setuptools import setup, find_packages
from distutils.core import setup

setup(
    name = "zddfz",   # 对外的模块名字
    version = "1.0",    # 版本号
    description = "自动打分",   # 信息描述
    author = "keyee",# 作者
    author_email = "du1872779171@163.com",
    py_modules=["ASS"] # 要发布的模块
)
